setReplyingTo method
Sets the message being replied to.
message is the message to reply to, or null to clear the reply.
Implementation
void setReplyingTo(ChatMessage? message) {
_replyingTo = message;
notifyListeners();
}
Sets the message being replied to.
message is the message to reply to, or null to clear the reply.
void setReplyingTo(ChatMessage? message) {
_replyingTo = message;
notifyListeners();
}