CdxChatLocalizationsEn class
The translations for English (en).
- Inheritance
-
- Object
- CdxChatLocalizations
- CdxChatLocalizationsEn
Constructors
- CdxChatLocalizationsEn([String locale = 'en'])
Properties
- block_user → String
-
Block user action label
no setteroverride
- cancel → String
-
Cancel button text
no setteroverride
- chat → String
-
Title for chat section
no setteroverride
- confirm → String
-
Confirm button text
no setteroverride
- delete → String
-
Delete action label
no setteroverride
- delete_message → String
-
Title for delete message dialog
no setteroverride
- end → String
-
Submit button text
no setteroverride
- error_loading_messages → String
-
Error message when messages fail to load
no setteroverride
- error_sending_message → String
-
Error message when sending a message fails
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- localeName → String
-
finalinherited
- message_deleted → String
-
Text shown for deleted messages
no setteroverride
- message_empty → String
-
Error message when message is empty
no setteroverride
- next → String
-
Next button text
no setteroverride
- no_messages → String
-
Message shown when there are no messages
no setteroverride
- q_block_user → String
-
Confirmation question for blocking a user
no setteroverride
- q_delete_message → String
-
Confirmation question for deleting a message
no setteroverride
- q_report_message → String
-
Question for reporting a message
no setteroverride
- q_report_user → String
-
Question for reporting/blocking a user
no setteroverride
- q_unblock_user → String
-
Confirmation question for unblocking a user
no setteroverride
- reply → String
-
Reply action label
no setteroverride
- replying_to → String
-
Label showing who you are replying to
no setteroverride
- report → String
-
Report action label
no setteroverride
- report_done → String
-
Success message after submitting a report
no setteroverride
- report_user → String
-
Report user checkbox label
no setteroverride
- retry → String
-
Retry button text
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- send → String
-
Button text to send a message
no setteroverride
- today → String
-
Label for today's date in date separator
no setteroverride
- type_a_message → String
-
Placeholder text for message input field
no setteroverride
- unblock_user → String
-
Unblock user action label
no setteroverride
- yesterday → String
-
Label for yesterday's date in date separator
no setteroverride
Methods
-
message_too_long(
int maxLength) → String -
Error message when message is too long
override
-
message_too_many_lines(
int maxLines) → String -
Error message when message has too many lines
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited