replyToMessageId property
ID of the message this is replying to, if any.
null for regular messages, non-null for replies.
Implementation
final String? replyToMessageId;
ID of the message this is replying to, if any.
null for regular messages, non-null for replies.
final String? replyToMessageId;