replyToSnapshot property

ChatReplySnapshot? replyToSnapshot
final

Snapshot of the message being replied to, if any.

Contains minimal information needed to display the reply preview. null for regular messages, non-null for replies.

Implementation

final ChatReplySnapshot? replyToSnapshot;