ChatTheme class abstract

Theme configuration for the chat package.

This interface allows customization of colors and styling used throughout the chat widgets. If not provided, the package will use default values based on the current Theme from the BuildContext.

Implementers

Constructors

ChatTheme()

Properties

avatarBackgroundColor Color
Background color for avatars.
no setter
avatarRadius double
Avatar radius.
no setter
backgroundColor Color
Background color for the chat view.
no setter
cardRadius BorderRadius
Border radius for card elements.
no setter
deletedBubbleBorderRadius double
Border radius for deleted message bubbles.
no setter
deletedBubbleColor Color
Color for deleted message bubbles.
no setter
deletedBubbleTextStyle TextStyle
Text style for deleted message bubbles.
no setter
error Color
Error color for delete actions and error messages.
no setter
hashCode int
The hash code for this object.
no setterinherited
inputBackgroundColor Color
Background color for the input field.
no setter
inputBorderColor Color
Border color for the input field.
no setter
inputBorderRadius double
Border radius for the input field.
no setter
inputMaxHeight double
Maximum height for the input field.
no setter
inputPadding EdgeInsets
Padding for the input field.
no setter
inputTextColor Color
Text color for the input field.
no setter
listPadding EdgeInsets
Padding for the message list.
no setter
mainBackground Color
Main background color (typically used for text in dark mode).
no setter
mainText Color
Main text color (typically used for backgrounds in dark mode).
no setter
messageSpacing double
Spacing between messages.
no setter
minorText Color
Minor text color for secondary text.
no setter
myBubbleAuthorStyle TextStyle
Author name style for my messages.
no setter
myBubbleBorderRadius double
Border radius for my message bubbles.
no setter
myBubbleColor Color
Color for my message bubbles.
no setter
myBubblePadding EdgeInsets
Padding for my message bubbles.
no setter
myBubbleTextStyle TextStyle
Text style for my message bubbles.
no setter
otherBubbleAuthorStyle TextStyle
Author name style for other users' messages.
no setter
otherBubbleBorderRadius double
Border radius for other users' message bubbles.
no setter
otherBubbleColor Color
Color for other users' message bubbles.
no setter
otherBubblePadding EdgeInsets
Padding for other users' message bubbles.
no setter
otherBubbleTextStyle TextStyle
Text style for other users' message bubbles.
no setter
primary Color
Primary color used for avatars and accent elements.
no setter
replyAuthorStyle TextStyle
Text style for reply author name.
no setter
replyBorderRadius double
Border radius for reply indicator.
no setter
replyIndicatorColor Color
Color for reply indicator.
no setter
replyPadding EdgeInsets
Padding for reply indicator.
no setter
replyTextStyle TextStyle
Text style for reply preview text.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemBubbleBorderRadius double
Border radius for system message bubbles.
no setter
systemBubbleColor Color
Color for system message bubbles.
no setter
systemBubblePadding EdgeInsets
Padding for system message bubbles.
no setter
systemBubbleTextStyle TextStyle
Text style for system message bubbles.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited