DefaultChatTheme class

Default implementation of ChatTheme that uses Theme.of.

This implementation extracts colors from the current Flutter theme, making it compatible with any Material Design theme.

Implemented types

Constructors

DefaultChatTheme(BuildContext context)
const

Properties

avatarBackgroundColor Color
Background color for avatars.
no setteroverride
avatarRadius double
Avatar radius.
no setteroverride
backgroundColor Color
Background color for the chat view.
no setteroverride
cardRadius BorderRadius
Border radius for card elements.
no setteroverride
context BuildContext
final
deletedBubbleBorderRadius double
Border radius for deleted message bubbles.
no setteroverride
deletedBubbleColor Color
Color for deleted message bubbles.
no setteroverride
deletedBubbleTextStyle TextStyle
Text style for deleted message bubbles.
no setteroverride
error Color
Error color for delete actions and error messages.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
inputBackgroundColor Color
Background color for the input field.
no setteroverride
inputBorderColor Color
Border color for the input field.
no setteroverride
inputBorderRadius double
Border radius for the input field.
no setteroverride
inputMaxHeight double
Maximum height for the input field.
no setteroverride
inputPadding EdgeInsets
Padding for the input field.
no setteroverride
inputTextColor Color
Text color for the input field.
no setteroverride
listPadding EdgeInsets
Padding for the message list.
no setteroverride
mainBackground Color
Main background color (typically used for text in dark mode).
no setteroverride
mainText Color
Main text color (typically used for backgrounds in dark mode).
no setteroverride
messageSpacing double
Spacing between messages.
no setteroverride
minorText Color
Minor text color for secondary text.
no setteroverride
myBubbleAuthorStyle TextStyle
Author name style for my messages.
no setteroverride
myBubbleBorderRadius double
Border radius for my message bubbles.
no setteroverride
myBubbleColor Color
Color for my message bubbles.
no setteroverride
myBubblePadding EdgeInsets
Padding for my message bubbles.
no setteroverride
myBubbleTextStyle TextStyle
Text style for my message bubbles.
no setteroverride
otherBubbleAuthorStyle TextStyle
Author name style for other users' messages.
no setteroverride
otherBubbleBorderRadius double
Border radius for other users' message bubbles.
no setteroverride
otherBubbleColor Color
Color for other users' message bubbles.
no setteroverride
otherBubblePadding EdgeInsets
Padding for other users' message bubbles.
no setteroverride
otherBubbleTextStyle TextStyle
Text style for other users' message bubbles.
no setteroverride
primary Color
Primary color used for avatars and accent elements.
no setteroverride
replyAuthorStyle TextStyle
Text style for reply author name.
no setteroverride
replyBorderRadius double
Border radius for reply indicator.
no setteroverride
replyIndicatorColor Color
Color for reply indicator.
no setteroverride
replyPadding EdgeInsets
Padding for reply indicator.
no setteroverride
replyTextStyle TextStyle
Text style for reply preview text.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemBubbleBorderRadius double
Border radius for system message bubbles.
no setteroverride
systemBubbleColor Color
Color for system message bubbles.
no setteroverride
systemBubblePadding EdgeInsets
Padding for system message bubbles.
no setteroverride
systemBubbleTextStyle TextStyle
Text style for system message bubbles.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited