ChatReportProvider constructor

ChatReportProvider(
  1. ChatService service,
  2. dynamic onUserBlocked()
)

Creates a new ChatReportProvider.

service is used to send the report to the server. onUserBlocked is called when a user is successfully blocked.

Implementation

ChatReportProvider(this.service, this.onUserBlocked);