messageBuilder property
Custom message builder. The third parameter is the callback to scroll to a replied message.
Implementation
final Widget Function(BuildContext, ChatMessage, void Function(String messageId))? messageBuilder;
Custom message builder. The third parameter is the callback to scroll to a replied message.
final Widget Function(BuildContext, ChatMessage, void Function(String messageId))? messageBuilder;