replyPreviewBuilder property
Custom reply preview builder. The third parameter is the callback to scroll to the replied message.
Implementation
final Widget Function(BuildContext, ChatMessage, void Function(String messageId))? replyPreviewBuilder;
Custom reply preview builder. The third parameter is the callback to scroll to the replied message.
final Widget Function(BuildContext, ChatMessage, void Function(String messageId))? replyPreviewBuilder;