MessageBubble class
Default message bubble widget.
This is ONLY a default: it can be replaced via builder.
Supports:
- Avatar
- Author name
- My/other bubbles
- Reply preview
- System messages
- Deleted messages
- Long-press → reply
- Applied theme
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MessageBubble
Constructors
- MessageBubble({Key? key, required ChatMessage message, required String currentUserId, required ChatTheme theme, VoidCallback? onLongPress, VoidCallback? onAvatarTap, bool showAvatar = true, bool showAuthorName = true})
-
Creates a new MessageBubble.
const
Properties
- currentUserId → String
-
ID of the current user.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDeleted → bool
-
no setter
- isMyMessage → bool
-
no setter
- isSystem → bool
-
no setter
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- message → ChatMessage
-
The message to display.
final
- onAvatarTap → VoidCallback?
-
Callback when avatar is tapped.
final
- onLongPress → VoidCallback?
-
Callback when bubble is long-pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAuthorName → bool
-
Whether to show the author name.
final
- showAvatar → bool
-
Whether to show the avatar.
final
- theme → ChatTheme
-
Theme to use for styling.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited