cdx_chat library
A Flutter package for managing chat with support for messages, replies, and user blocking.
Classes
- CdxChatLocalizations
-
Callers can lookup localized strings with an instance of CdxChatLocalizations
returned by
CdxChatLocalizations.of(context). - ChatAppActions
- Callbacks for app-level actions like showing snackbars and dialogs.
- ChatConfig
- Configuration for the chat module.
- ChatController
- Controller based on ChangeNotifier, compatible with Provider.
- ChatMessage
- Represents a chat message with support for replies and system messages.
- ChatProvider
- Provider for managing chat state and UI interactions.
- ChatReplySnapshot
- Minimal snapshot of a quoted message.
- ChatReportProvider
- Provider for managing the chat message/user reporting flow.
- ChatReportReason
- A reason for reporting a chat message.
- ChatService
- Abstract interface that defines all backend-side behavior for chat.
- ChatTextStyle
- Text style configuration for chat widgets.
- ChatTheme
- Theme configuration for the chat package.
- ChatView
- Complete and configurable widget for chat.
- DateFormatter
- Utility class for formatting dates.
- DefaultChatAppActions
- Default implementation of ChatAppActions using Flutter's standard widgets.
- DefaultChatTextStyle
- Default implementation of ChatTextStyle using Theme.of.
- DefaultChatTheme
- Default implementation of ChatTheme that uses Theme.of.
- MessageBubble
- Default message bubble widget.
- ReportMessageBottomSheet
- Bottom sheet for reporting a chat message.
- UserInfo
- Information about the current user.
Enums
- ChatReportStep
- Steps in the report flow.
Constants
-
chatReportReasons
→ const List<
ChatReportReason> - Predefined list of report reasons for chat messages.