ChatConfig constructor
Creates a new ChatConfig.
maxMessageLength is the maximum number of characters allowed in a message.
maxLines is the maximum number of lines allowed in a message.
Implementation
const ChatConfig({
this.maxMessageLength = 1000,
this.maxLines = 20,
});