replyToSnapshot property
Snapshot of the message being replied to, if any.
Contains minimal information needed to display the reply preview.
null for regular messages, non-null for replies.
Implementation
final ChatReplySnapshot? replyToSnapshot;
Snapshot of the message being replied to, if any.
Contains minimal information needed to display the reply preview.
null for regular messages, non-null for replies.
final ChatReplySnapshot? replyToSnapshot;